@@ -1,8 +1,4 @@
-from functools import partial
-from multiprocessing import Pool
-from pathlib import Path
-
-from six.moves.urllib.parse import urlparse
+from typing import BinaryIO
 
 from rebotics_sdk.advanced import remote_loaders
 from rebotics_sdk.constants import RCDB
@@ -14,7 +10,20 @@ class FileUploadError(Exception):
         self.response = response
 
 
-class RCDBImportFlow(object):
+class PresignedURLFileUploader:
+    def __init__(self, destination: dict):
+        self.destination = destination
+
+    def upload(self, file: BinaryIO, progress_bar: bool = True, **kwargs) -> None:
+        response = remote_loaders.upload(self.destination, file, progress_bar, **kwargs)
+        if response.status_code > 300:
+            raise FileUploadError(
+                'Failed to upload destination. Response: {}. {}'.format(response.status_code, response.content),
+                response
+            )
+
+
+class RCDBImportFlow(PresignedURLFileUploader):
     def __init__(self, rcdb_interface, retailer, retailer_model, extension):
         """
         Process wrapper with automatic API hooks
@@ -27,6 +36,7 @@ class RCDBImportFlow(object):
         self.rcdb = rcdb_interface
         self.import_request = self.rcdb.data_import(retailer, retailer_model, extension)
         self.rcdb_id = self.import_request['id']
+        super().__init__(destination=self.import_request['destination'])
 
     def __enter__(self):
         self.rcdb.update(self.rcdb_id, status=RCDB.EXPORT_IN_PROGRESS)
@@ -38,14 +48,6 @@ class RCDBImportFlow(object):
         else:
             self.rcdb.update(self.rcdb_id, status=RCDB.EXPORT_DONE)
 
-    def upload_file(self, packed, progress_bar=False):
-        destination = self.import_request['destination']
-        response = remote_loaders.upload(destination, packed, progress_bar=progress_bar)
-        if response.status_code > 300:
-            raise FileUploadError(
-                'Failed to upload destination. Response: {}. {}'.format(response.status_code, response.content),
-                response)
-
 
 class ReboticsClassificationDatabase(object):
     def __init__(self, *args, **kwargs):
@@ -54,7 +56,7 @@ class ReboticsClassificationDatabase(object):
     def create(self, retailer, model, backup_type='feature_vectors', extension='rcdb'):
         return self.provider.rcdb_create({
             'retailer': retailer,
-            'facenet_model': model,
+            'model_codename': model,
             'extension': extension,
             'backup_type': backup_type,
         })
