@@ -1,7 +1,9 @@
+import os
 from collections import OrderedDict
+from io import BytesIO
+from typing import BinaryIO
 
 import requests
-import six
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
 from tqdm import tqdm
 
@@ -43,7 +45,8 @@ def format_request_body(fields):
         return fields
 
 
-def upload(destination, file, progress_bar=False, filename='features_backup.rcdb', ):
+def upload(destination: dict, file: BinaryIO, progress_bar: bool = False,
+           filename: str = 'features_backup.rcdb') -> requests.Response:
     """
 
     :param dict destination: an S3 presigned upload object
@@ -53,8 +56,10 @@ def upload(destination, file, progress_bar=False, filename='features_backup.rcdb
     :return:
     """
     url = destination["url"]
-
     provider = destination.get('provider', 'aws-s3')
+    if provider not in {'aws-s3', 'azure-blob', 'aws-s3-put'}:
+        raise ValueError('File upload destination is not configured')  # Don't ignore if provider is incorrect
+
     if provider == 'aws-s3':
         fields = destination.get('fields', None)
         if fields is None:
@@ -89,12 +94,25 @@ def upload(destination, file, progress_bar=False, filename='features_backup.rcdb
                 timeout=HTTP_TIMEOUTS,
             )
     elif provider == 'azure-blob' or provider == 'aws-s3-put':
-        return requests.put(
-            url,
-            data=file,
-            headers=destination.get('headers'),
-            timeout=HTTP_TIMEOUTS,
-        )
+        if not progress_bar:
+            return requests.put(
+                url,
+                data=file,
+                headers=destination.get('headers'),
+                timeout=HTTP_TIMEOUTS,
+            )
+
+        file.seek(0, os.SEEK_END)
+        file_size = file.tell()
+        file.seek(0)
+
+        with tqdm.wrapattr(file, 'read', total=file_size) as wrapped_file:
+            return requests.put(
+                url,
+                data=wrapped_file,
+                headers=destination.get('headers'),
+                timeout=HTTP_TIMEOUTS,
+            )
 
 
 def download(source, destination=None, progress_bar=False):
@@ -112,7 +130,7 @@ def process_file_response(response, destination, progress_bar=False):
     is_file = False
 
     if destination is None:
-        fp = six.BytesIO()
+        fp = BytesIO()
     elif hasattr(destination, 'write') and hasattr(destination, 'read'):
         # it is a file-like object
         fp = destination
