@@ -6,20 +6,29 @@ import pathlib
 import time
 from multiprocessing.pool import Pool
 from time import sleep
+from typing import Optional, IO
+from warnings import warn
 
 import click
 import humanize
+import requests
+import tqdm
 from prettytable import PrettyTable
 
 from rebotics_sdk.cli.common import shell, configure, roles, set_token
 from .draw import draw_annotated_drawing
 from .renderers import format_full_table
-from .utils import ReboticsCLIContext, app_dir, pass_rebotics_context, read_saved_role, process_role, \
-    downloads_with_threads, save_masks, get_segmentation, refresh_url, get_segmentation_mode
+from .utils import (
+    ReboticsCLIContext, app_dir, pass_rebotics_context, read_saved_role, process_role,
+    downloads_with_threads, save_masks, get_segmentation, get_segmentation_mode, refresh_urls_in_threads,
+)
 from ..advanced.flows import FileUploadError
-from ..advanced.packers import ClassificationDatabasePacker, ClassificationDatabaseException, \
+from ..advanced.packers import (
+    ClassificationDatabasePacker,
+    ClassificationDatabaseException,
     DuplicateFeatureVectorsException
-from ..providers import AdminProvider, RetailerProvider
+)
+from ..providers import AdminProvider, RetailerProvider, ProviderHTTPClientException
 from ..utils import uri_validator, get_filename_from_url
 
 OPENCV_INSTALLED = True
@@ -30,13 +39,14 @@ except ModuleNotFoundError:
 
 
 @click.group()
+@click.option('--api-verbosity', default=0, type=click.IntRange(0, 3), help='Display request detail')
 @click.option('-f', '--format', default='table', type=click.Choice(['table', 'id', 'json']), help='Result rendering')
 @click.option('-v', '--verbose', is_flag=True, help='Enables verbose mode')
 @click.option('-c', '--config', type=click.Path(), default='admin.json', help="Specify what config.json to use")
 @click.option('-r', '--role', default=lambda: read_saved_role('admin'), help="Key to specify what admin to use")
 @click.version_option()
 @click.pass_context
-def api(ctx, format, verbose, config, role):
+def api(ctx, format, verbose, config, role, api_verbosity):
     """
     Admin CLI tool to communicate with dataset API
     """
@@ -46,8 +56,10 @@ def api(ctx, format, verbose, config, role):
         role,
         format,
         verbose,
+        api_verbosity,
         os.path.join(app_dir, config),
-        provider_class=AdminProvider
+        provider_class=AdminProvider,
+        click_context=ctx,
     )
 
 
@@ -255,6 +267,113 @@ def models(ctx, retailer, v2):
         raise click.ClickException(str(exc))
 
 
+@api.command()
+@click.option('-t', '--target', type=click.Path(file_okay=True, dir_okay=True), default='.', help="Target directory")
+@click.option('-b', '--bucket', type=click.STRING, prompt=True, help="Bucket domain, e.g. bucket-us-west-2.aws.com")
+@click.option('-m', '--model', type=click.STRING, default=None, help="Specify a concrete model to download")
+@click.option('-p', '--posix', type=click.BOOL, is_flag=True, default=False, help="Flag to use posix path")
+@click.argument('retailer')
+@pass_rebotics_context
+def setup_models(ctx, retailer, model, target, bucket, posix):
+    """Download and setup models for local configuration"""
+    models_v2 = ctx.provider.get_models_conf_v2(codename=retailer)
+
+    models_to_fetch = list(models_v2.keys())
+
+    # don't support statistical data for now
+    models_to_fetch.remove('statistical_data')
+
+    if model is not None:
+        model_conf = models_v2.get(model)
+        if model_conf is not None:
+            models_to_fetch = [model]
+
+        else:
+            raise click.ClickException(f"Model {model} not found")
+
+    ctx.verbose_log(f"Models to fetch: {models_to_fetch}")
+
+    folder_target = pathlib.Path(target)
+    if folder_target.is_file():
+        folder_target = folder_target.parent
+        ctx.verbose_log(f"Downloading models to {folder_target}")
+
+    if not folder_target.exists():
+        ctx.verbose_log(f"Creating folder {folder_target}")
+        folder_target.mkdir(parents=True)
+
+    file_download_tasks = []
+
+    for model in tqdm.tqdm(models_to_fetch, desc='Downloading models', disable=not ctx.do_progress_bar()):
+        model_conf = models_v2.get(model)
+        if model_conf is None:
+            ctx.verbose_log(f"Model at key {model} is not set")
+            continue
+
+        if model == 'classification_database':
+            model_codename = model_conf['model']['codename']
+        else:
+            model_codename = model_conf['codename']
+
+        target = folder_target / f"{model_codename}.json"
+
+        click.echo(f"Processing: {model_codename}")
+
+        file_urls = {}
+        for key, value in model_conf.items():
+            if (key in ['model_file_path', 'pb_path', 'file_key'] or key.endswith('_path')) and value is not None:
+                model_folder = target.parent / model_codename
+                model_folder.mkdir(parents=True, exist_ok=True)
+
+                file_urls[key] = {
+                    'url': f'https://{bucket}/{value}',
+                    'key': value,
+                    'local_path': model_folder / pathlib.Path(value).name
+                }
+
+        if not len(file_urls):
+            click.echo(f"\nIn service: {model}, model {model_codename} does not have an assigned file\n")
+            continue
+
+        ctx.verbose_log(f"Refreshing {len(file_urls)} urls")
+
+        refreshed_urls = refresh_urls_in_threads(
+            ctx,
+            [v['url'] for v in file_urls.values()]
+        )
+
+        # source to destination mapping
+        download_tasks = []
+        for refreshed_url in refreshed_urls:
+            for key, value in file_urls.items():
+                file_key = value['key']
+
+                if file_key in refreshed_url:
+                    download_tasks.append(
+                        (refreshed_url, value['local_path'])
+                    )
+
+        ctx.verbose_log(f"Files: {download_tasks}")
+        file_download_tasks += download_tasks
+
+        # bring back together
+        model_conf.update({
+            k: str(v['local_path'].as_posix()) if posix else str(v['local_path'])
+            for k, v in file_urls.items()
+        })
+
+        models_configuration_json = json.dumps(model_conf, indent=4)
+
+        ctx.verbose_log(
+            f"Models configuration for {model} to be written to {target} is: \n {models_configuration_json}"
+        )
+        target.write_text(models_configuration_json)
+
+    ctx.verbose_log("Downloading files to local storage")
+    downloads_with_threads(ctx, file_download_tasks, max(1, len(file_download_tasks)))
+    click.echo("Done")
+
+
 @api.command()
 @click.argument('retailer', type=click.STRING)
 @click.argument('url', type=click.STRING)
@@ -275,11 +394,10 @@ def set_retailer_url(ctx, retailer, url):
 @click.option('-l', '--labels', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-f', '--features', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-c', '--check-duplicates', is_flag=True, help="MD5 checker simple")
-@click.option('-m', '--model-type', type=str, default='facenet')
-@click.option('-n', '--model-codename', type=str)
+@click.option('--model-type', type=str, default='arcface')
 @pass_rebotics_context
 def pack_and_import_classification_db(
-    ctx,
+    ctx: ReboticsCLIContext,
     retailer,
     model,
     images,
@@ -287,7 +405,6 @@ def pack_and_import_classification_db(
     features,
     check_duplicates,
     model_type,
-    model_codename,
 ):
     """Pack classification database to single .rcdb file and import it to the Rebotics Admin
 
@@ -305,6 +422,8 @@ admin pack-classification-db --features features.txt --labels labels.txt --image
 
 admin import_classification_db --retailer delta --model test_code classification.rcdb
     """
+    warn("This command is deprecated, please use: fvm rcdb pack", DeprecationWarning, stacklevel=2)
+
     ext = ClassificationDatabasePacker.extension
     with ctx.provider.rcdb.import_flow(retailer, model, ext) as flow:
         if ctx.verbose:
@@ -318,7 +437,7 @@ admin import_classification_db --retailer delta --model test_code classification
             progress_bar=True,
             check_duplicates=check_duplicates,
             model_type=model_type,
-            model_codename=model_codename,
+            model_codename=model,
         )
         if ctx.verbose:
             click.echo("Packing from provided values: \n"
@@ -339,7 +458,7 @@ admin import_classification_db --retailer delta --model test_code classification
             click.echo("Import request: {}".format(flow.import_request))
 
         try:
-            flow.upload_file(packed, progress_bar=True)
+            flow.upload(packed)
         except FileUploadError as exc:
             click.echo(str(exc))
             raise
@@ -369,7 +488,7 @@ def import_classification_db(ctx, retailer, model, filepath):
         if ctx.verbose:
             click.echo("Import request: {}".format(flow.import_request))
         with open(filepath, 'rb') as packed:
-            flow.upload_file(packed, progress_bar=True)
+            flow.upload(packed)
 
     click.echo("Import completed. Reference database id: {}".format(flow.import_request['id']))
 
@@ -425,6 +544,8 @@ db/
         admin pack-classification-db --features features.txt --labels labels.txt --images ./custom_folder/ --target classification.rcdb
 
     """
+    warn("This command is deprecated, please use: fvm rcdb pack", DeprecationWarning, stacklevel=2)
+
     target = pathlib.Path(target)
     if target.is_dir():
         target = target / "classification_db{}.{}".format(
@@ -453,24 +574,6 @@ db/
     click.echo('Written to {}'.format(packed))
 
 
-@api.group(name='rcdb')
-def rcdb_group():
-    click.echo("RCDB in rebotics admin is deprecated and will be removed in version 0.13.0")
-
-
-@rcdb_group.command(name="previews-fs")
-@click.argument("argument", type=click.STRING)
-@click.option('-o', "--output", type=click.Path(exists=True, dir_okay=True, file_okay=False), default=".")
-@click.option('-c', '--concurrency', default=8, type=click.INT)
-@pass_rebotics_context
-def rcdb_previews_fs(ctx, argument, output, concurrency):
-    """
-    Prepare previews file structure by the id, filepath or file url of the JSON formatted backup
-    Make sure that extension is a valid JSON and extension in the admin is set like that
-    """
-    click.echo("Use `fvm rcdb unpack` command instead")
-
-
 @api.group()
 def stitching():
     pass
@@ -602,16 +705,20 @@ def stitching_setup(ctx, argument, concurrency, output, draw):
 
     ctx.verbose_log(f"Registered files for downloading: {len(files_to_load)}")
 
-    downloads_with_threads(files_to_load, concurrency=len(files_to_load))
+    downloads_with_threads(ctx, files_to_load, concurrency=len(files_to_load))
     click.echo(f"Stitching setup complete in: {output}")
 
     if draw:
         segmentation_per_image = get_segmentation(segmentation_filepath)
         mode = get_segmentation_mode(segmentation_per_image)
         if mode == 'remote_url':
-            refreshed_urls = refresh_url(ctx.provider.refresh_url, segmentation_per_image)
+            refreshed_urls = refresh_urls_in_threads(
+                ctx, [
+                    image['remote_url']
+                    for image in segmentation_per_image
+                ])
             # save masks in output/all_masks
-            save_masks(output, refreshed_urls)
+            save_masks(ctx, output, refreshed_urls)
 
         draw_annotated_drawing(
             root_folder=output,
@@ -625,3 +732,80 @@ api.add_command(shell, 'shell')
 api.add_command(roles, 'roles')
 api.add_command(configure, 'configure')
 api.add_command(set_token, 'set_token')
+
+
+@api.command()
+@click.argument('filepath', type=click.Path(exists=True, dir_okay=False, path_type=pathlib.Path))
+@click.option('-c', '--codename', type=click.STRING)
+@pass_rebotics_context
+def upload_model_file(ctx, filepath: pathlib.Path, codename: Optional[str]):
+    """
+    Upload model file using presigned PUT.
+
+    Usage:
+        admin -r r3dev upload-model-file "path_to_file.pth" --codename="SomeCodeName"
+    """
+    codename: str = codename or filepath.stem.replace(' ', '_')
+    ctx.verbose_log('Started Model File upload')
+    try:
+        response = ctx.provider.upload_model_file(codename, filepath)
+    except (ProviderHTTPClientException, FileUploadError) as exc:
+        raise click.ClickException(str(exc))
+
+    if ctx.format in {'id', 'json'}:
+        ctx.format_result(response)
+    else:
+        click.echo(f'Uploaded Model File with id={response["id"]} to the url: \n{response["link"]}')
+
+
+@api.command()
+@click.argument('model', type=click.STRING)
+@click.option('-c', '--codename', type=click.STRING, required=True)  # Should be unique
+@click.option('-t', '--title', default=None, callback=lambda ctx, _, value: value if value else ctx.params['codename'])
+@click.option('-y', '--yaml-template', type=click.File())
+@click.option('--model-file-id', type=click.INT)
+@click.argument('extra_args', nargs=-1, type=click.UNPROCESSED)
+@pass_rebotics_context
+def create_model(ctx, model: str, codename: str, title: str, yaml_template: Optional[IO],
+                 model_file_id: Optional[int], extra_args: tuple):
+    """
+    Upload nn models. Pass extra_args separated by spaces in format: field_name=field_value.
+
+    Usage examples:
+        admin -r r3dev create-model tensorflow_model -c tf_codename is_main=True type=tf_light_od meta_file=210
+        admin -r r3dev create-model yolo_v5 -c yolo_codename -y "path_to_yaml.yml" --model-file-id 210
+        admin -r r3dev create-model yolo_v5 -c yolo_codename -y "path_to_yaml.yml"
+            --model-file-id=$(admin -r r3dev -f id upload-model-file "path_to_file.pth" -c "FileCodeName")
+    """
+    data = {
+        'title': title,
+        'codename': codename,
+    }
+    for arg in extra_args:
+        key, value = arg.split('=')
+        data[key] = value
+
+    if yaml_template:
+        data['yaml_configuration'] = yaml_template.read()
+    if model_file_id:
+        data['model'] = model_file_id
+
+    ctx.verbose_log('Started model upload')
+    try:
+        response = ctx.provider.create_model(model, data)
+    except ProviderHTTPClientException as exc:
+        message = str(exc)
+
+        error_response = exc.response
+        if error_response is not None:
+            if error_response.status_code == requests.codes.bad_request:
+                message = error_response._content
+            elif error_response.status_code == requests.codes.forbidden:
+                message = f'Forbidden for url: {error_response.url}'
+
+        raise click.ClickException(message)
+
+    if ctx.format in {'id', 'json'}:
+        ctx.format_result(response)
+    else:
+        click.echo(f'Uploaded {model} model with id={response["id"]} to the url: \n{response["link"]}')
