@@ -10,7 +10,6 @@ from pprint import pformat
 
 import chardet
 import click
-import six
 import yaml
 
 from rebotics_sdk.cli.renderers import format_full_table
@@ -254,7 +253,7 @@ def option_default_from_configurations(conf_name):
 @pass_rebotics_context
 def configure(ctx, user, password, host):
     """Fetch token, save it and use the role of it."""
-    provider = ctx.provider_class(host=host)
+    provider = ctx.provider_class(host=host, api_verbosity=ctx.api_verbosity)
     ctx.update_configuration(
         host=host,
     )
@@ -300,7 +299,7 @@ def set_token(ctx, host, token):
 @click.argument('source_file', type=click.File('r'))
 @pass_rebotics_context
 def run(ctx, source_file):
-    click.echo(six.exec_(source_file.read(), {
+    click.echo(exec(source_file.read(), {
         'ctx': ctx,
         'provider': ctx.provider,
     }))
