@@ -19,13 +19,14 @@ from ..utils import download_file, mkdir_p, get_filename_from_url
 
 
 @click.group()
+@click.option('--api-verbosity', default=0, type=click.IntRange(0, 3), help='Display request detail')
 @click.option('-f', '--format', default='table', type=click.Choice(['table', 'id', 'json']))
 @click.option('-v', '--verbose', is_flag=True, help='Enables verbose mode')
 @click.option('-c', '--config', type=click.Path(), default='dataset.json', help="Specify what config.json to use")
 @click.option('-r', '--role', default=lambda: read_saved_role('dataset'), help="Key to specify what dataset to use")
 @click.version_option()
 @click.pass_context
-def api(ctx, format, verbose, config, role):
+def api(ctx, format, verbose, config, role, api_verbosity):
     """
     Dataset CLI tool to communicate with dataset API
     """
@@ -35,8 +36,10 @@ def api(ctx, format, verbose, config, role):
         role,
         format,
         verbose,
+        api_verbosity,
         os.path.join(app_dir, config),
-        provider_class=DatasetProvider
+        provider_class=DatasetProvider,
+        click_context=ctx,
     )
 
 
