@@ -22,7 +22,7 @@ from .renderers import format_processing_action_output, format_full_table
 from .tasks import task_create_processing_action_for_image, upload_preview_task, \
     task_download_processing_action, task_recalculate_processing, task_cancel_processing, task_requeue_processing
 from .utils import ReboticsCLIContext, pass_rebotics_context, app_dir, process_role, read_saved_role, task_runner, \
-    download_file_from_dict, guess_input_type
+    download_file_from_dict, guess_input_type, fetch_scans
 from ..advanced import remote_loaders
 from ..constants import CVAT_EXPORT_WORKSPACE
 from ..providers import RetailerProvider, ProviderHTTPClientException
@@ -32,13 +32,14 @@ logger = logging.getLogger(__name__)
 
 
 @click.group()
+@click.option('--api-verbosity', default=0, type=click.IntRange(0, 3), help='Display request detail')
 @click.option('-f', '--format', default='table', type=click.Choice(['table', 'id', 'json']))
 @click.option('-v', '--verbose', is_flag=True, help='Enables verbose mode')
 @click.option('-c', '--config', type=click.Path(), default='retailer.json', help="Specify what config.json to use")
 @click.option('-r', '--role', default=lambda: read_saved_role('retailer'), help="Key to specify what retailer to use")
 @click.version_option()
 @click.pass_context
-def api(ctx, format, verbose, config, role):
+def api(ctx, format, verbose, config, role, api_verbosity):
     """
     Retailer CLI tool to communicate with retailer API
     """
@@ -49,8 +50,10 @@ def api(ctx, format, verbose, config, role):
         role,
         format,
         verbose,
+        api_verbosity,
         os.path.join(app_dir, config),
-        provider_class=RetailerProvider
+        provider_class=RetailerProvider,
+        click_context=ctx,
     )
 
 
@@ -345,7 +348,7 @@ PROCESSING_STATUSES = {
 
 @api.command()
 @click.option('-s', '--store', type=click.INT, help='Store ID')
-@click.option('--status', type=click.Choice(PROCESSING_STATUSES.keys()))
+@click.option('--status', type=click.Choice(list(PROCESSING_STATUSES.keys())))
 @click.option('-p', '--page', type=click.INT, default=1)
 @click.option('-r', '--page-size', type=click.INT, default=10)
 @pass_rebotics_context
@@ -585,8 +588,8 @@ def processing_action(click_context, ctx, processing_id):
     setattr(ctx, 'processing_id_list', processing_ids)
 
     if click_context.invoked_subcommand is None:
-        result = ctx.provider.processing_action_detail(processing_ids[0])
-        format_processing_action_output([result, ], ctx.format)
+        processing_actions_list = fetch_scans(ctx, processing_ids)
+        format_processing_action_output(processing_actions_list, ctx.format)
 
 
 @processing_action.command(name='realogram')
@@ -988,6 +991,28 @@ def processing_core_result(ctx, target, concurrency):
     executor.shutdown(wait=True)
 
 
+@processing_action.command('for-voting')
+@click.option('-a', '--all-data', type=click.BOOL, is_flag=True, default=False,
+              help='Flag to not filter realogram products without UPC from User')
+@pass_rebotics_context
+def processing_action_for_voting(ctx, all_data: bool):
+    """
+    Usage:
+        retailer -r epsilon processing-action id1,id2,id3 for-voting -a
+    """
+    if len(ctx.processing_id_list) > 200:
+        raise click.ClickException('The request is limited to 200 scans at a time.')
+
+    ctx.verbose_log('Exporting scans/realogram products data...')
+    try:
+        response = ctx.provider.get_voting_data(ctx.processing_id_list, all_data)
+    except ProviderHTTPClientException as exc:
+        raise click.ClickException(str(exc))
+
+    ctx.verbose_log('Successfully exported the following data:')
+    ctx.format_result(response, force_format='json')
+
+
 @api.group(name='fv')
 def feature_vectors():
     """
