@@ -47,3 +47,9 @@ class DownloadImagesFormat(object):
 
 
 CVAT_EXPORT_WORKSPACE = 'RetechLabs'
+
+
+class RCDBBaseFileNames:
+    LABELS = 'labels.txt'
+    FEATURES = 'features.txt'
+    META = 'meta.json'
