@@ -1,11 +1,27 @@
+from unittest import TestCase
 from unittest.mock import MagicMock, patch
 
-from django.dispatch import receiver
-from rest_framework import status
-from rest_framework.test import APITestCase, APIRequestFactory
+import pytest
 
-from rebotics_sdk.hook.signals import PROCESSING_FINISH_SUCCESS
-from rebotics_sdk.hook.views import WebhookHandlerViewSet
+try:
+    from django.core.exceptions import ImproperlyConfigured as DjangoImproperlyConfigured
+except ImportError:
+    DjangoImproperlyConfigured = ImportError
+
+try:
+    from django.dispatch import receiver
+    from rest_framework import status
+    from rest_framework.test import APITestCase, APIRequestFactory
+
+    from rebotics_sdk.hook.signals import PROCESSING_FINISH_SUCCESS
+    from rebotics_sdk.hook.views import WebhookHandlerViewSet
+except DjangoImproperlyConfigured:
+    APITestCase = TestCase
+    no_django_setup = True
+else:
+    no_django_setup = False
+
+pytestmark = pytest.mark.skipif(no_django_setup, reason='There is no Django setup')
 
 
 class SignalEmitterTestCase(APITestCase):
