@@ -2,8 +2,8 @@ from rest_framework import status
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-from rebotics_sdk.hook.serializers import WebhookDataSerializer
 from rebotics_sdk.hook import signals
+from rebotics_sdk.hook.serializers import WebhookDataSerializer
 
 
 class WebhookHandlerViewSet(APIView):
@@ -17,7 +17,8 @@ class WebhookHandlerViewSet(APIView):
         emitter = signals.SignalEmitter(
             retailer=retailer_code,
             event=serializer.validated_data['event'],
-            payload=serializer.validated_data['payload'],
+            # do not parse payload, send it as is
+            payload=request.data['payload'],
         )
         emitter.emit()
 
