@@ -3,17 +3,36 @@ import logging
 import sys
 import time
 import typing
+import warnings
 from collections import OrderedDict
-from copy import copy
+from copy import copy, deepcopy
+from functools import wraps
 from pprint import pformat
+from urllib.parse import urlparse, urljoin
 from uuid import uuid4
 
+try:
+    import curl
+except ImportError:
+    curl = None
+
 import requests
-from six import wraps
-from six.moves.urllib.parse import urljoin
-from six.moves.urllib.parse import urlparse
+
+__all__ = (
+    'ProviderHTTPClientException', 'RetryableException', 'ProviderHTTPServiceException', 'flatten_nested_object',
+    'ProviderRequestProxy', 'UniqueRequestProxy', 'remote_service', 'ReboticsBaseProvider', 'PageResult',
+    'APIPageIterator', 'required_model_params',
+)
 
 logger = logging.getLogger(__name__)
+
+provider_logger = logging.getLogger('provider_logger')
+provider_logger.setLevel(logging.INFO)
+c_handler = logging.StreamHandler()
+c_format = logging.Formatter("{message}", style="{")
+c_handler.setFormatter(c_format)
+provider_logger.addHandler(c_handler)
+
 MAX_RETRIES = 5
 DEFAULT_TIMEOUT = 180
 
@@ -57,6 +76,7 @@ class ProviderRequestProxy(object):
     def __init__(self, *, url, headers, timeout, retries=MAX_RETRIES, host=None, retry_delay=5, **kwargs):
         self.url = url
         self.headers = headers
+        self.api_verbosity = kwargs.get('api_verbosity', 0)
         self.timeout = timeout
         self.retries = retries
         self.host = host
@@ -85,6 +105,8 @@ class ProviderRequestProxy(object):
             data['stream'] = request_kwargs['stream']
         if 'params' in request_kwargs:
             data['params'] = request_kwargs['params']
+        if 'hooks' in request_kwargs:
+            data['hooks'] = request_kwargs['hooks']
 
         if 'json' in data and 'data' in data:
             raise ValueError('You need to use either `json` or `data` parameter, not both.')
@@ -170,8 +192,28 @@ class ProviderRequestProxy(object):
                 response.reason
             ), response=response)
 
+    def verbose_logging(self, method, **kwargs):
+        if self.api_verbosity == 1:
+            provider_logger.info(f'\n{method.upper()} {kwargs.get("url")}')
+        elif self.api_verbosity == 2:
+            provider_logger.info(f'\n{method.upper()} {kwargs.get("url")}')
+            for key, value in kwargs.get('headers', {}).items():
+                provider_logger.info(f'{key}: {value}')
+            if method in ('post', 'patch', 'put'):
+                message = json.dumps(kwargs.get("data", kwargs.get("json", kwargs.get("params"))), indent=4)
+                provider_logger.info(f'\n{message}\n')
+        elif self.api_verbosity == 3:
+            if curl is None:
+                warnings.warn('Please install requests-to-curl')
+                return
+            params = deepcopy(kwargs)
+            params.pop('timeout')
+            request = requests.Request(method, **params).prepare()
+            provider_logger.info(curl.parse(request, print_it=False, return_it=True))
+
     def request_with_retry(self, method, **request_arguments):
         request_arguments = self.augment_request_arguments(**request_arguments)
+        self.verbose_logging(method, **request_arguments)
         retries = 0
         retry_errors = []
         response = None
@@ -274,14 +316,16 @@ def remote_service(path, headers=None, timeout=None, json=True, raw=False, **opt
 
             url = provider.build_url(path)
             raw_override = kwargs.get('raw')
+            retries = options.pop('retries', provider.retries)
             proxy_opts = copy(provider.proxy_config)
             proxy_opts.update(options)
 
             session = provider.proxy_class(
                 url=url,
                 headers=headers,
+                api_verbosity=provider.api_verbosity,
                 timeout=timeout or provider.timeout,
-                retries=provider.retries,
+                retries=retries,
                 json=json,
                 raw=raw_override or raw,
                 host=provider.host,
@@ -314,6 +358,7 @@ class ReboticsBaseProvider(object):
         self.domain = urlparse(self.host).netloc
         self.headers = kwargs.get('headers', {})
         self.data = kwargs.get('data', {})
+        self.api_verbosity = kwargs.get('api_verbosity', 0)
         self.session = None
         self.requests = requests
 
@@ -410,6 +455,7 @@ class APIPageIterator:
             # do whatever with the data
             pass
     """
+
     def __init__(self, method, initial_page=1, **filter_params):
         self.method = method
         self.filter_params = filter_params  # page size can be passed as an optional value
