@@ -2,9 +2,13 @@ import base64
 import hmac
 from collections import OrderedDict
 from hashlib import sha256
+from typing import TYPE_CHECKING
 
 from rebotics_sdk.advanced import remote_loaders
-from rebotics_sdk.providers import ReboticsBaseProvider, remote_service, PageResult
+from rebotics_sdk.providers import PageResult, ReboticsBaseProvider, remote_service
+
+if TYPE_CHECKING:
+    from requests.models import Response
 
 
 class FVMProvider(ReboticsBaseProvider):
@@ -53,12 +57,13 @@ class FVMProvider(ReboticsBaseProvider):
     def finish(self, pk):
         return self.session.post(pk=pk)
 
-    def upload_file(self, file_io, filename):
+    def upload_file(self, file_io, filename, progress_bar=False):
         file_io.seek(0)
         request = self.create_virtual_upload(filename)
         remote_loaders.upload(
             request['destination'],
-            file_io
+            file_io,
+            progress_bar=progress_bar,
         )
         return self.finish(request['id'])
 
@@ -157,5 +162,12 @@ class FVMProvider(ReboticsBaseProvider):
     def download(self, url, destination=None, progress_bar=False):
         if not url.startswith(self.host):
             url = self.build_url(url)
-        response = self.session.get(url=url, stream=True)
-        return remote_loaders.process_file_response(response, destination, progress_bar)
+
+        def process_file_response(resp: 'Response', **request_arguments) -> None:
+            downloaded_file = None
+            if resp.ok:
+                downloaded_file = remote_loaders.process_file_response(resp, destination, progress_bar)
+            resp._downloaded_file = downloaded_file
+
+        response = self.session.get(url=url, stream=True, hooks={'response': process_file_response})
+        return response._downloaded_file  # noqa
