@@ -1,11 +1,11 @@
 import json
+from typing import List, Sequence
 
-import six
-
-from rebotics_sdk.providers.utils import hash_file, accept_file
-from .base import ReboticsBaseProvider, remote_service, PageResult, UniqueRequestProxy
 from ..advanced.flows import FeatureVectorFlow
 from ..constants import CVAT_EXPORT_WORKSPACE
+from ..providers.utils import hash_file, accept_file
+
+from .base import ReboticsBaseProvider, remote_service, PageResult, UniqueRequestProxy
 
 
 class RetailerProvider(ReboticsBaseProvider):
@@ -114,17 +114,17 @@ class RetailerProvider(ReboticsBaseProvider):
             assert isinstance(store_planogram, int)
             data['store_planogram'] = store_planogram
         if aisle:
-            assert isinstance(aisle, six.string_types)
+            assert isinstance(aisle, str)
             data['aisle'] = aisle
         if section:
-            assert isinstance(section, six.string_types)
+            assert isinstance(section, str)
             data['section'] = section
 
         if klt_json:
             # encode KLT to string as it is accepted in API
             if isinstance(klt_json, dict):
                 klt = json.dumps(klt_json)
-            elif isinstance(klt_json, six.string_types):
+            elif isinstance(klt_json, str):
                 klt = klt_json
             else:
                 # TODO: add path support and IO support
@@ -517,3 +517,10 @@ class RetailerProvider(ReboticsBaseProvider):
     @remote_service('/api/v1/realograms/scans/{scan_id}/')
     def get_scan_info(self, scan_id):
         return self.session.get(scan_id=scan_id)
+
+    @remote_service('/api/v1/realograms/voting-data-export/')
+    def get_voting_data(self, scan_ids: Sequence[int], all_data: bool) -> List[dict]:
+        return self.session.post(json={
+            'scans': scan_ids,
+            'filter_code_from_user': not all_data,
+        })
