@@ -1,8 +1,7 @@
 import hashlib
 import re
 from functools import partial
-
-from six import BytesIO
+from io import BytesIO
 
 
 def hash_file(file, block_size=65536):
