@@ -1,7 +1,7 @@
-import unittest
 import random
 import string
-from urllib.parse import urljoin, urlparse, unquote
+import unittest
+from urllib.parse import urlparse, unquote
 
 from rebotics_sdk.providers import FVMProvider
 
