@@ -1,5 +1,6 @@
 from unittest import TestCase
-from mock import patch, MagicMock
+from unittest.mock import patch, MagicMock
+
 from rebotics_sdk.providers.base import ProviderRequestProxy
 from rebotics_sdk.providers.retailer import RetailerProvider
 
