@@ -1,10 +1,11 @@
 from unittest import TestCase
-from mock import patch, MagicMock
+from unittest.mock import patch, MagicMock
+
 from click.testing import CliRunner
 
-from rebotics_sdk.providers.retailer import RetailerProvider
-from rebotics_sdk.cli.utils import ReboticsScriptsConfiguration
 from rebotics_sdk.cli.retailer import api
+from rebotics_sdk.cli.utils import ReboticsScriptsConfiguration
+from rebotics_sdk.providers.retailer import RetailerProvider
 
 
 class RetailerProviderTestCase(TestCase):
